Struct objc2_cloud_kit::CKContainer

source ·
#[repr(C)]
pub struct CKContainer { /* private fields */ }
Available on crate feature CKContainer only.

Implementations

source

impl CKContainer

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new() -> Retained<Self>

source

pub unsafe fn defaultContainer() -> Retained<CKContainer>

source

pub unsafe fn containerWithIdentifier( container_identifier: &NSString ) -> Retained<CKContainer>

source

pub unsafe fn containerIdentifier(&self) -> Option<Retained<NSString>>

source

pub unsafe fn addOperation(&self, operation: &CKOperation)

Available on crate feature CKOperation only.
source

impl CKContainer

Database

source

pub unsafe fn privateCloudDatabase(&self) -> Retained<CKDatabase>

Available on crate feature CKDatabase only.
source

pub unsafe fn publicCloudDatabase(&self) -> Retained<CKDatabase>

Available on crate feature CKDatabase only.
source

pub unsafe fn sharedCloudDatabase(&self) -> Retained<CKDatabase>

Available on crate feature CKDatabase only.
source

pub unsafe fn databaseWithDatabaseScope( &self, database_scope: CKDatabaseScope ) -> Retained<CKDatabase>

Available on crate feature CKDatabase only.
source

impl CKContainer

AccountStatus

source

pub unsafe fn accountStatusWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(CKAccountStatus, *mut NSError)> )

Available on crate feature block2 only.
source

impl CKContainer

ApplicationPermission

source

pub unsafe fn statusForApplicationPermission_completionHandler( &self, application_permission: CKApplicationPermissions, completion_handler: CKApplicationPermissionBlock )

👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate feature block2 only.
source

pub unsafe fn requestApplicationPermission_completionHandler( &self, application_permission: CKApplicationPermissions, completion_handler: CKApplicationPermissionBlock )

👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate feature block2 only.
source

impl CKContainer

UserRecords

source

pub unsafe fn fetchUserRecordIDWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(*mut CKRecordID, *mut NSError)> )

Available on crate features CKRecordID and block2 only.
source

pub unsafe fn discoverAllIdentitiesWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(*mut NSArray<CKUserIdentity>, *mut NSError)> )

👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features CKUserIdentity and block2 only.
source

pub unsafe fn discoverUserIdentityWithEmailAddress_completionHandler( &self, email: &NSString, completion_handler: &Block<dyn Fn(*mut CKUserIdentity, *mut NSError)> )

👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features CKUserIdentity and block2 only.
source

pub unsafe fn discoverUserIdentityWithPhoneNumber_completionHandler( &self, phone_number: &NSString, completion_handler: &Block<dyn Fn(*mut CKUserIdentity, *mut NSError)> )

👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features CKUserIdentity and block2 only.
source

pub unsafe fn discoverUserIdentityWithUserRecordID_completionHandler( &self, user_record_id: &CKRecordID, completion_handler: &Block<dyn Fn(*mut CKUserIdentity, *mut NSError)> )

👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features CKRecordID and CKUserIdentity and block2 only.
source

impl CKContainer

Sharing

source

pub unsafe fn fetchShareParticipantWithEmailAddress_completionHandler( &self, email_address: &NSString, completion_handler: &Block<dyn Fn(*mut CKShareParticipant, *mut NSError)> )

Available on crate features CKShareParticipant and block2 only.
source

pub unsafe fn fetchShareParticipantWithPhoneNumber_completionHandler( &self, phone_number: &NSString, completion_handler: &Block<dyn Fn(*mut CKShareParticipant, *mut NSError)> )

Available on crate features CKShareParticipant and block2 only.
source

pub unsafe fn fetchShareParticipantWithUserRecordID_completionHandler( &self, user_record_id: &CKRecordID, completion_handler: &Block<dyn Fn(*mut CKShareParticipant, *mut NSError)> )

Available on crate features CKRecordID and CKShareParticipant and block2 only.
source

pub unsafe fn fetchShareMetadataWithURL_completionHandler( &self, url: &NSURL, completion_handler: &Block<dyn Fn(*mut CKShareMetadata, *mut NSError)> )

Available on crate features CKShareMetadata and block2 only.
source

pub unsafe fn acceptShareMetadata_completionHandler( &self, metadata: &CKShareMetadata, completion_handler: &Block<dyn Fn(*mut CKShare, *mut NSError)> )

Available on crate features CKRecord and CKShare and CKShareMetadata and block2 only.
source

impl CKContainer

CKLongLivedOperations

source

pub unsafe fn fetchAllLongLivedOperationIDsWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(*mut NSArray<CKOperationID>, *mut NSError)> )

Available on crate features CKOperation and block2 only.
source

pub unsafe fn fetchLongLivedOperationWithID_completionHandler( &self, operation_id: &CKOperationID, completion_handler: &Block<dyn Fn(*mut CKOperation, *mut NSError)> )

Available on crate features CKOperation and block2 only.

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.