#[repr(C)]pub struct CKFetchRecordZoneChangesOperation { /* private fields */ }Available on crate features
CKDatabaseOperation and CKFetchRecordZoneChangesOperation and CKOperation only.Implementations
sourceimpl CKFetchRecordZoneChangesOperation
impl CKFetchRecordZoneChangesOperation
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithRecordZoneIDs_configurationsByRecordZoneID( this: Allocated<Self>, record_zone_i_ds: &NSArray<CKRecordZoneID>, configurations_by_record_zone_id: Option<&NSDictionary<CKRecordZoneID, CKFetchRecordZoneChangesConfiguration>> ) -> Retained<Self>
Available on crate feature
CKRecordZoneID only.pub unsafe fn recordZoneIDs(&self) -> Option<Retained<NSArray<CKRecordZoneID>>>
Available on crate feature
CKRecordZoneID only.pub unsafe fn setRecordZoneIDs( &self, record_zone_i_ds: Option<&NSArray<CKRecordZoneID>> )
Available on crate feature
CKRecordZoneID only.pub unsafe fn configurationsByRecordZoneID( &self ) -> Option<Retained<NSDictionary<CKRecordZoneID, CKFetchRecordZoneChangesConfiguration>>>
Available on crate feature
CKRecordZoneID only.pub unsafe fn setConfigurationsByRecordZoneID( &self, configurations_by_record_zone_id: Option<&NSDictionary<CKRecordZoneID, CKFetchRecordZoneChangesConfiguration>> )
Available on crate feature
CKRecordZoneID only.pub unsafe fn fetchAllChanges(&self) -> bool
pub unsafe fn setFetchAllChanges(&self, fetch_all_changes: bool)
pub unsafe fn recordChangedBlock(&self) -> *mut Block<dyn Fn(NonNull<CKRecord>)>
👎Deprecated: Use recordWasChangedBlock instead, which surfaces per-record errors
Available on crate features
CKRecord and block2 only.pub unsafe fn setRecordChangedBlock( &self, record_changed_block: Option<&Block<dyn Fn(NonNull<CKRecord>)>> )
👎Deprecated: Use recordWasChangedBlock instead, which surfaces per-record errors
Available on crate features
CKRecord and block2 only.pub unsafe fn recordWasChangedBlock( &self ) -> *mut Block<dyn Fn(NonNull<CKRecordID>, *mut CKRecord, *mut NSError)>
Available on crate features
CKRecord and CKRecordID and block2 only.pub unsafe fn setRecordWasChangedBlock( &self, record_was_changed_block: Option<&Block<dyn Fn(NonNull<CKRecordID>, *mut CKRecord, *mut NSError)>> )
Available on crate features
CKRecord and CKRecordID and block2 only.pub unsafe fn recordWithIDWasDeletedBlock( &self ) -> *mut Block<dyn Fn(NonNull<CKRecordID>, NonNull<CKRecordType>)>
Available on crate features
CKRecord and CKRecordID and block2 only.pub unsafe fn setRecordWithIDWasDeletedBlock( &self, record_with_id_was_deleted_block: Option<&Block<dyn Fn(NonNull<CKRecordID>, NonNull<CKRecordType>)>> )
Available on crate features
CKRecord and CKRecordID and block2 only.pub unsafe fn recordZoneChangeTokensUpdatedBlock( &self ) -> *mut Block<dyn Fn(NonNull<CKRecordZoneID>, *mut CKServerChangeToken, *mut NSData)>
Available on crate features
CKRecordZoneID and CKServerChangeToken and block2 only.pub unsafe fn setRecordZoneChangeTokensUpdatedBlock( &self, record_zone_change_tokens_updated_block: Option<&Block<dyn Fn(NonNull<CKRecordZoneID>, *mut CKServerChangeToken, *mut NSData)>> )
Available on crate features
CKRecordZoneID and CKServerChangeToken and block2 only.pub unsafe fn recordZoneFetchCompletionBlock( &self ) -> *mut Block<dyn Fn(NonNull<CKRecordZoneID>, *mut CKServerChangeToken, *mut NSData, Bool, *mut NSError)>
Available on crate features
CKRecordZoneID and CKServerChangeToken and block2 only.pub unsafe fn setRecordZoneFetchCompletionBlock( &self, record_zone_fetch_completion_block: Option<&Block<dyn Fn(NonNull<CKRecordZoneID>, *mut CKServerChangeToken, *mut NSData, Bool, *mut NSError)>> )
Available on crate features
CKRecordZoneID and CKServerChangeToken and block2 only.pub unsafe fn fetchRecordZoneChangesCompletionBlock( &self ) -> *mut Block<dyn Fn(*mut NSError)>
Available on crate feature
block2 only.pub unsafe fn setFetchRecordZoneChangesCompletionBlock( &self, fetch_record_zone_changes_completion_block: Option<&Block<dyn Fn(*mut NSError)>> )
Available on crate feature
block2 only.sourceimpl CKFetchRecordZoneChangesOperation
impl CKFetchRecordZoneChangesOperation
Methods declared on superclass NSObject
sourceimpl CKFetchRecordZoneChangesOperation
impl CKFetchRecordZoneChangesOperation
Deprecated
pub unsafe fn initWithRecordZoneIDs_optionsByRecordZoneID( this: Allocated<Self>, record_zone_i_ds: &NSArray<CKRecordZoneID>, options_by_record_zone_id: Option<&NSDictionary<CKRecordZoneID, CKFetchRecordZoneChangesOptions>> ) -> Retained<Self>
👎Deprecated
Available on crate feature
CKRecordZoneID only.pub unsafe fn optionsByRecordZoneID( &self ) -> Option<Retained<NSDictionary<CKRecordZoneID, CKFetchRecordZoneChangesOptions>>>
👎Deprecated
Available on crate feature
CKRecordZoneID only.pub unsafe fn setOptionsByRecordZoneID( &self, options_by_record_zone_id: Option<&NSDictionary<CKRecordZoneID, CKFetchRecordZoneChangesOptions>> )
👎Deprecated
Available on crate feature
CKRecordZoneID only.Methods from Deref<Target = CKDatabaseOperation>
pub unsafe fn database(&self) -> Option<Retained<CKDatabase>>
Available on crate feature
CKDatabase only.pub unsafe fn setDatabase(&self, database: Option<&CKDatabase>)
Available on crate feature
CKDatabase only.Methods from Deref<Target = CKOperation>
pub unsafe fn configuration(&self) -> Retained<CKOperationConfiguration>
pub unsafe fn setConfiguration( &self, configuration: Option<&CKOperationConfiguration> )
pub unsafe fn group(&self) -> Option<Retained<CKOperationGroup>>
Available on crate feature
CKOperationGroup only.pub unsafe fn setGroup(&self, group: Option<&CKOperationGroup>)
Available on crate feature
CKOperationGroup only.pub unsafe fn operationID(&self) -> Retained<CKOperationID>
pub unsafe fn longLivedOperationWasPersistedBlock(&self) -> *mut Block<dyn Fn()>
Available on crate feature
block2 only.pub unsafe fn setLongLivedOperationWasPersistedBlock( &self, long_lived_operation_was_persisted_block: Option<&Block<dyn Fn()>> )
Available on crate feature
block2 only.pub unsafe fn container(&self) -> Option<Retained<CKContainer>>
👎Deprecated: Use CKOperationConfiguration
Available on crate feature
CKContainer only.pub unsafe fn setContainer(&self, container: Option<&CKContainer>)
👎Deprecated: Use CKOperationConfiguration
Available on crate feature
CKContainer only.pub unsafe fn allowsCellularAccess(&self) -> bool
👎Deprecated: Use CKOperationConfiguration
pub unsafe fn setAllowsCellularAccess(&self, allows_cellular_access: bool)
👎Deprecated: Use CKOperationConfiguration
pub unsafe fn isLongLived(&self) -> bool
👎Deprecated: Use CKOperationConfiguration
pub unsafe fn setLongLived(&self, long_lived: bool)
👎Deprecated: Use CKOperationConfiguration
pub unsafe fn timeoutIntervalForRequest(&self) -> NSTimeInterval
👎Deprecated: Use CKOperationConfiguration
pub unsafe fn setTimeoutIntervalForRequest( &self, timeout_interval_for_request: NSTimeInterval )
👎Deprecated: Use CKOperationConfiguration
pub unsafe fn timeoutIntervalForResource(&self) -> NSTimeInterval
👎Deprecated: Use CKOperationConfiguration
pub unsafe fn setTimeoutIntervalForResource( &self, timeout_interval_for_resource: NSTimeInterval )
👎Deprecated: Use CKOperationConfiguration
Methods from Deref<Target = NSOperation>
pub unsafe fn start(&self)
pub unsafe fn main(&self)
pub unsafe fn isCancelled(&self) -> bool
pub unsafe fn cancel(&self)
pub unsafe fn isExecuting(&self) -> bool
pub unsafe fn isFinished(&self) -> bool
pub unsafe fn isConcurrent(&self) -> bool
pub unsafe fn isAsynchronous(&self) -> bool
pub unsafe fn isReady(&self) -> bool
pub unsafe fn addDependency(&self, op: &NSOperation)
pub unsafe fn removeDependency(&self, op: &NSOperation)
pub unsafe fn dependencies(&self) -> Retained<NSArray<NSOperation>>
Available on crate feature
NSArray only.pub unsafe fn queuePriority(&self) -> NSOperationQueuePriority
pub unsafe fn setQueuePriority(&self, queue_priority: NSOperationQueuePriority)
pub unsafe fn completionBlock(&self) -> *mut Block<dyn Fn()>
Available on crate feature
block2 only.pub unsafe fn setCompletionBlock( &self, completion_block: Option<&Block<dyn Fn()>> )
Available on crate feature
block2 only.pub unsafe fn waitUntilFinished(&self)
pub unsafe fn threadPriority(&self) -> f64
👎Deprecated: Not supported
pub unsafe fn setThreadPriority(&self, thread_priority: f64)
👎Deprecated: Not supported
pub unsafe fn qualityOfService(&self) -> NSQualityOfService
Available on crate feature
NSObjCRuntime only.pub unsafe fn setQualityOfService(&self, quality_of_service: NSQualityOfService)
Available on crate feature
NSObjCRuntime only.pub unsafe fn name(&self) -> Option<Retained<NSString>>
Available on crate feature
NSString only.pub unsafe fn setName(&self, name: Option<&NSString>)
Available on crate feature
NSString only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.