#[repr(C)]pub struct CKLocationSortDescriptor { /* private fields */ }Available on crate feature
CKLocationSortDescriptor only.Implementations
sourceimpl CKLocationSortDescriptor
impl CKLocationSortDescriptor
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
pub unsafe fn initWithKey_relativeLocation( this: Allocated<Self>, key: &NSString, relative_location: &CLLocation ) -> Retained<Self>
Available on crate feature
objc2-core-location only.pub unsafe fn initWithCoder( this: Allocated<Self>, a_decoder: &NSCoder ) -> Retained<Self>
pub unsafe fn relativeLocation(&self) -> Retained<CLLocation>
Available on crate feature
objc2-core-location only.sourceimpl CKLocationSortDescriptor
impl CKLocationSortDescriptor
Methods declared on superclass NSSortDescriptor
pub unsafe fn sortDescriptorWithKey_ascending( key: Option<&NSString>, ascending: bool ) -> Retained<Self>
pub unsafe fn sortDescriptorWithKey_ascending_selector( key: Option<&NSString>, ascending: bool, selector: Option<Sel> ) -> Retained<Self>
pub unsafe fn initWithKey_ascending( this: Allocated<Self>, key: Option<&NSString>, ascending: bool ) -> Retained<Self>
pub unsafe fn initWithKey_ascending_selector( this: Allocated<Self>, key: Option<&NSString>, ascending: bool, selector: Option<Sel> ) -> Retained<Self>
pub unsafe fn sortDescriptorWithKey_ascending_comparator( key: Option<&NSString>, ascending: bool, cmptr: NSComparator ) -> Retained<Self>
Available on crate feature
block2 only.pub unsafe fn initWithKey_ascending_comparator( this: Allocated<Self>, key: Option<&NSString>, ascending: bool, cmptr: NSComparator ) -> Retained<Self>
Available on crate feature
block2 only.Methods from Deref<Target = NSSortDescriptor>
pub unsafe fn key(&self) -> Option<Retained<NSString>>
Available on crate feature
NSString only.pub unsafe fn ascending(&self) -> bool
pub unsafe fn selector(&self) -> Option<Sel>
pub unsafe fn allowEvaluation(&self)
pub unsafe fn comparator( &self ) -> *mut Block<dyn Fn(NonNull<AnyObject>, NonNull<AnyObject>) -> NSComparisonResult>
Available on crate features
NSObjCRuntime and block2 only.pub unsafe fn compareObject_toObject( &self, object1: &AnyObject, object2: &AnyObject ) -> NSComparisonResult
Available on crate feature
NSObjCRuntime only.pub unsafe fn reversedSortDescriptor(&self) -> Retained<AnyObject>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.