Struct objc2_cloud_kit::CKNotificationInfo
source · #[repr(C)]pub struct CKNotificationInfo { /* private fields */ }Available on crate feature
CKSubscription only.Implementations
sourceimpl CKNotificationInfo
impl CKNotificationInfo
pub unsafe fn alertBody(&self) -> Option<Retained<NSString>>
pub unsafe fn setAlertBody(&self, alert_body: Option<&NSString>)
pub unsafe fn alertLocalizationKey(&self) -> Option<Retained<NSString>>
pub unsafe fn setAlertLocalizationKey( &self, alert_localization_key: Option<&NSString> )
pub unsafe fn alertLocalizationArgs( &self ) -> Option<Retained<NSArray<CKRecordFieldKey>>>
Available on crate feature
CKRecord only.pub unsafe fn setAlertLocalizationArgs( &self, alert_localization_args: Option<&NSArray<CKRecordFieldKey>> )
Available on crate feature
CKRecord only.pub unsafe fn title(&self) -> Option<Retained<NSString>>
pub unsafe fn setTitle(&self, title: Option<&NSString>)
pub unsafe fn titleLocalizationKey(&self) -> Option<Retained<NSString>>
pub unsafe fn setTitleLocalizationKey( &self, title_localization_key: Option<&NSString> )
pub unsafe fn titleLocalizationArgs( &self ) -> Option<Retained<NSArray<CKRecordFieldKey>>>
Available on crate feature
CKRecord only.pub unsafe fn setTitleLocalizationArgs( &self, title_localization_args: Option<&NSArray<CKRecordFieldKey>> )
Available on crate feature
CKRecord only.pub unsafe fn subtitle(&self) -> Option<Retained<NSString>>
pub unsafe fn setSubtitle(&self, subtitle: Option<&NSString>)
pub unsafe fn subtitleLocalizationKey(&self) -> Option<Retained<NSString>>
pub unsafe fn setSubtitleLocalizationKey( &self, subtitle_localization_key: Option<&NSString> )
pub unsafe fn subtitleLocalizationArgs( &self ) -> Option<Retained<NSArray<CKRecordFieldKey>>>
Available on crate feature
CKRecord only.pub unsafe fn setSubtitleLocalizationArgs( &self, subtitle_localization_args: Option<&NSArray<CKRecordFieldKey>> )
Available on crate feature
CKRecord only.pub unsafe fn alertActionLocalizationKey(&self) -> Option<Retained<NSString>>
pub unsafe fn setAlertActionLocalizationKey( &self, alert_action_localization_key: Option<&NSString> )
pub unsafe fn alertLaunchImage(&self) -> Option<Retained<NSString>>
pub unsafe fn setAlertLaunchImage(&self, alert_launch_image: Option<&NSString>)
pub unsafe fn soundName(&self) -> Option<Retained<NSString>>
pub unsafe fn setSoundName(&self, sound_name: Option<&NSString>)
pub unsafe fn desiredKeys(&self) -> Option<Retained<NSArray<CKRecordFieldKey>>>
Available on crate feature
CKRecord only.pub unsafe fn setDesiredKeys( &self, desired_keys: Option<&NSArray<CKRecordFieldKey>> )
Available on crate feature
CKRecord only.pub unsafe fn shouldBadge(&self) -> bool
pub unsafe fn setShouldBadge(&self, should_badge: bool)
pub unsafe fn shouldSendContentAvailable(&self) -> bool
pub unsafe fn setShouldSendContentAvailable( &self, should_send_content_available: bool )
pub unsafe fn shouldSendMutableContent(&self) -> bool
pub unsafe fn setShouldSendMutableContent( &self, should_send_mutable_content: bool )
pub unsafe fn category(&self) -> Option<Retained<NSString>>
pub unsafe fn setCategory(&self, category: Option<&NSString>)
pub unsafe fn collapseIDKey(&self) -> Option<Retained<NSString>>
pub unsafe fn setCollapseIDKey(&self, collapse_id_key: Option<&NSString>)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.