Struct objc2_cloud_kit::CKOperation

source ·
#[repr(C)]
pub struct CKOperation { /* private fields */ }
Available on crate feature CKOperation only.

Implementations

source

impl CKOperation

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn configuration(&self) -> Retained<CKOperationConfiguration>

source

pub unsafe fn setConfiguration( &self, configuration: Option<&CKOperationConfiguration> )

source

pub unsafe fn group(&self) -> Option<Retained<CKOperationGroup>>

Available on crate feature CKOperationGroup only.
source

pub unsafe fn setGroup(&self, group: Option<&CKOperationGroup>)

Available on crate feature CKOperationGroup only.
source

pub unsafe fn operationID(&self) -> Retained<CKOperationID>

source

pub unsafe fn longLivedOperationWasPersistedBlock(&self) -> *mut Block<dyn Fn()>

Available on crate feature block2 only.
source

pub unsafe fn setLongLivedOperationWasPersistedBlock( &self, long_lived_operation_was_persisted_block: Option<&Block<dyn Fn()>> )

Available on crate feature block2 only.
source

impl CKOperation

Methods declared on superclass NSObject

source

pub unsafe fn new() -> Retained<Self>

source

impl CKOperation

CKOperationDeprecated

source

pub unsafe fn container(&self) -> Option<Retained<CKContainer>>

👎Deprecated: Use CKOperationConfiguration
Available on crate feature CKContainer only.
source

pub unsafe fn setContainer(&self, container: Option<&CKContainer>)

👎Deprecated: Use CKOperationConfiguration
Available on crate feature CKContainer only.
source

pub unsafe fn allowsCellularAccess(&self) -> bool

👎Deprecated: Use CKOperationConfiguration
source

pub unsafe fn setAllowsCellularAccess(&self, allows_cellular_access: bool)

👎Deprecated: Use CKOperationConfiguration
source

pub unsafe fn isLongLived(&self) -> bool

👎Deprecated: Use CKOperationConfiguration
source

pub unsafe fn setLongLived(&self, long_lived: bool)

👎Deprecated: Use CKOperationConfiguration
source

pub unsafe fn timeoutIntervalForRequest(&self) -> NSTimeInterval

👎Deprecated: Use CKOperationConfiguration
source

pub unsafe fn setTimeoutIntervalForRequest( &self, timeout_interval_for_request: NSTimeInterval )

👎Deprecated: Use CKOperationConfiguration
source

pub unsafe fn timeoutIntervalForResource(&self) -> NSTimeInterval

👎Deprecated: Use CKOperationConfiguration
source

pub unsafe fn setTimeoutIntervalForResource( &self, timeout_interval_for_resource: NSTimeInterval )

👎Deprecated: Use CKOperationConfiguration

Methods from Deref<Target = NSOperation>

source

pub unsafe fn start(&self)

source

pub unsafe fn main(&self)

source

pub unsafe fn isCancelled(&self) -> bool

source

pub unsafe fn cancel(&self)

source

pub unsafe fn isExecuting(&self) -> bool

source

pub unsafe fn isFinished(&self) -> bool

source

pub unsafe fn isConcurrent(&self) -> bool

source

pub unsafe fn isAsynchronous(&self) -> bool

source

pub unsafe fn isReady(&self) -> bool

source

pub unsafe fn addDependency(&self, op: &NSOperation)

source

pub unsafe fn removeDependency(&self, op: &NSOperation)

source

pub unsafe fn dependencies(&self) -> Retained<NSArray<NSOperation>>

Available on crate feature NSArray only.
source

pub unsafe fn queuePriority(&self) -> NSOperationQueuePriority

source

pub unsafe fn setQueuePriority(&self, queue_priority: NSOperationQueuePriority)

source

pub unsafe fn completionBlock(&self) -> *mut Block<dyn Fn()>

Available on crate feature block2 only.
source

pub unsafe fn setCompletionBlock( &self, completion_block: Option<&Block<dyn Fn()>> )

Available on crate feature block2 only.
source

pub unsafe fn waitUntilFinished(&self)

source

pub unsafe fn threadPriority(&self) -> f64

👎Deprecated: Not supported
source

pub unsafe fn setThreadPriority(&self, thread_priority: f64)

👎Deprecated: Not supported
source

pub unsafe fn qualityOfService(&self) -> NSQualityOfService

Available on crate feature NSObjCRuntime only.
source

pub unsafe fn setQualityOfService(&self, quality_of_service: NSQualityOfService)

Available on crate feature NSObjCRuntime only.
source

pub unsafe fn name(&self) -> Option<Retained<NSString>>

Available on crate feature NSString only.
source

pub unsafe fn setName(&self, name: Option<&NSString>)

Available on crate feature NSString only.

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.