Struct objc2_cloud_kit::CKOperationGroup
source · #[repr(C)]pub struct CKOperationGroup { /* private fields */ }Available on crate feature
CKOperationGroup only.Implementations
sourceimpl CKOperationGroup
impl CKOperationGroup
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithCoder( this: Allocated<Self>, a_decoder: &NSCoder ) -> Retained<Self>
pub unsafe fn operationGroupID(&self) -> Retained<NSString>
pub unsafe fn defaultConfiguration(&self) -> Retained<CKOperationConfiguration>
Available on crate feature
CKOperation only.pub unsafe fn setDefaultConfiguration( &self, default_configuration: Option<&CKOperationConfiguration> )
Available on crate feature
CKOperation only.pub unsafe fn name(&self) -> Option<Retained<NSString>>
pub unsafe fn setName(&self, name: Option<&NSString>)
pub unsafe fn quantity(&self) -> NSUInteger
pub unsafe fn setQuantity(&self, quantity: NSUInteger)
pub unsafe fn expectedSendSize(&self) -> CKOperationGroupTransferSize
pub unsafe fn setExpectedSendSize( &self, expected_send_size: CKOperationGroupTransferSize )
pub unsafe fn expectedReceiveSize(&self) -> CKOperationGroupTransferSize
pub unsafe fn setExpectedReceiveSize( &self, expected_receive_size: CKOperationGroupTransferSize )
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.