Struct objc2_cloud_kit::CKQueryNotification
source · #[repr(C)]pub struct CKQueryNotification { /* private fields */ }Available on crate feature
CKNotification only.Implementations
sourceimpl CKQueryNotification
impl CKQueryNotification
pub unsafe fn queryNotificationReason(&self) -> CKQueryNotificationReason
pub unsafe fn recordFields( &self ) -> Option<Retained<NSDictionary<NSString, AnyObject>>>
pub unsafe fn recordID(&self) -> Option<Retained<CKRecordID>>
Available on crate feature
CKRecordID only.pub unsafe fn databaseScope(&self) -> CKDatabaseScope
Available on crate feature
CKDatabase only.sourceimpl CKQueryNotification
impl CKQueryNotification
Methods declared on superclass CKNotification
Methods from Deref<Target = CKNotification>
pub unsafe fn notificationType(&self) -> CKNotificationType
pub unsafe fn notificationID(&self) -> Option<Retained<CKNotificationID>>
pub unsafe fn containerIdentifier(&self) -> Option<Retained<NSString>>
pub unsafe fn subscriptionOwnerUserRecordID( &self ) -> Option<Retained<CKRecordID>>
Available on crate feature
CKRecordID only.pub unsafe fn isPruned(&self) -> bool
pub unsafe fn subscriptionID(&self) -> Option<Retained<CKSubscriptionID>>
Available on crate feature
CKSubscription only.pub unsafe fn alertBody(&self) -> Option<Retained<NSString>>
👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
pub unsafe fn alertLocalizationKey(&self) -> Option<Retained<NSString>>
👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
pub unsafe fn alertLocalizationArgs( &self ) -> Option<Retained<NSArray<NSString>>>
👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
pub unsafe fn title(&self) -> Option<Retained<NSString>>
pub unsafe fn titleLocalizationKey(&self) -> Option<Retained<NSString>>
pub unsafe fn titleLocalizationArgs( &self ) -> Option<Retained<NSArray<NSString>>>
pub unsafe fn subtitle(&self) -> Option<Retained<NSString>>
pub unsafe fn subtitleLocalizationKey(&self) -> Option<Retained<NSString>>
pub unsafe fn subtitleLocalizationArgs( &self ) -> Option<Retained<NSArray<NSString>>>
pub unsafe fn alertActionLocalizationKey(&self) -> Option<Retained<NSString>>
👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
pub unsafe fn alertLaunchImage(&self) -> Option<Retained<NSString>>
👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
pub unsafe fn badge(&self) -> Option<Retained<NSNumber>>
👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
pub unsafe fn soundName(&self) -> Option<Retained<NSString>>
👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
pub unsafe fn category(&self) -> Option<Retained<NSString>>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.