Struct objc2_cloud_kit::CKRecord
source · #[repr(C)]pub struct CKRecord { /* private fields */ }Available on crate feature
CKRecord only.Implementations
sourceimpl CKRecord
impl CKRecord
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
pub unsafe fn initWithRecordType( this: Allocated<Self>, record_type: &CKRecordType ) -> Retained<Self>
pub unsafe fn initWithRecordType_recordID( this: Allocated<Self>, record_type: &CKRecordType, record_id: &CKRecordID ) -> Retained<Self>
Available on crate feature
CKRecordID only.pub unsafe fn initWithRecordType_zoneID( this: Allocated<Self>, record_type: &CKRecordType, zone_id: &CKRecordZoneID ) -> Retained<Self>
Available on crate feature
CKRecordZoneID only.pub unsafe fn recordType(&self) -> Retained<CKRecordType>
pub unsafe fn recordID(&self) -> Retained<CKRecordID>
Available on crate feature
CKRecordID only.pub unsafe fn recordChangeTag(&self) -> Option<Retained<NSString>>
pub unsafe fn creatorUserRecordID(&self) -> Option<Retained<CKRecordID>>
Available on crate feature
CKRecordID only.pub unsafe fn creationDate(&self) -> Option<Retained<NSDate>>
pub unsafe fn lastModifiedUserRecordID(&self) -> Option<Retained<CKRecordID>>
Available on crate feature
CKRecordID only.pub unsafe fn modificationDate(&self) -> Option<Retained<NSDate>>
pub unsafe fn objectForKey( &self, key: &CKRecordFieldKey ) -> Option<Retained<ProtocolObject<dyn CKRecordValue>>>
pub unsafe fn setObject_forKey( &self, object: Option<&ProtocolObject<dyn CKRecordValue>>, key: &CKRecordFieldKey )
pub unsafe fn allKeys(&self) -> Retained<NSArray<CKRecordFieldKey>>
pub unsafe fn allTokens(&self) -> Retained<NSArray<NSString>>
pub unsafe fn objectForKeyedSubscript( &self, key: &CKRecordFieldKey ) -> Option<Retained<ProtocolObject<dyn CKRecordValue>>>
pub unsafe fn setObject_forKeyedSubscript( &self, object: Option<&ProtocolObject<dyn CKRecordValue>>, key: &CKRecordFieldKey )
pub unsafe fn changedKeys(&self) -> Retained<NSArray<CKRecordFieldKey>>
pub unsafe fn encodeSystemFieldsWithCoder(&self, coder: &NSCoder)
Available on crate feature
CKReference only.pub unsafe fn parent(&self) -> Option<Retained<CKReference>>
Available on crate feature
CKReference only.pub unsafe fn setParent(&self, parent: Option<&CKReference>)
Available on crate feature
CKReference only.pub unsafe fn setParentReferenceFromRecord( &self, parent_record: Option<&CKRecord> )
pub unsafe fn setParentReferenceFromRecordID( &self, parent_record_id: Option<&CKRecordID> )
Available on crate feature
CKRecordID only.sourceimpl CKRecord
impl CKRecord
CKRecordKeyValueSettingConformance
pub unsafe fn encryptedValues( &self ) -> Retained<ProtocolObject<dyn CKRecordKeyValueSetting>>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.