Struct objc2_cloud_kit::CKRecordZoneNotification

source ·
#[repr(C)]
pub struct CKRecordZoneNotification { /* private fields */ }
Available on crate feature CKNotification only.

Implementations

source

impl CKRecordZoneNotification

source

pub unsafe fn recordZoneID(&self) -> Option<Retained<CKRecordZoneID>>

Available on crate feature CKRecordZoneID only.
source

pub unsafe fn databaseScope(&self) -> CKDatabaseScope

Available on crate feature CKDatabase only.
source

impl CKRecordZoneNotification

Methods declared on superclass CKNotification

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new() -> Retained<Self>

source

pub unsafe fn notificationFromRemoteNotificationDictionary( notification_dictionary: &NSDictionary ) -> Option<Retained<Self>>

Methods from Deref<Target = CKNotification>

source

pub unsafe fn notificationType(&self) -> CKNotificationType

source

pub unsafe fn notificationID(&self) -> Option<Retained<CKNotificationID>>

source

pub unsafe fn containerIdentifier(&self) -> Option<Retained<NSString>>

source

pub unsafe fn subscriptionOwnerUserRecordID( &self ) -> Option<Retained<CKRecordID>>

Available on crate feature CKRecordID only.
source

pub unsafe fn isPruned(&self) -> bool

source

pub unsafe fn subscriptionID(&self) -> Option<Retained<CKSubscriptionID>>

Available on crate feature CKSubscription only.
source

pub unsafe fn alertBody(&self) -> Option<Retained<NSString>>

👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
source

pub unsafe fn alertLocalizationKey(&self) -> Option<Retained<NSString>>

👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
source

pub unsafe fn alertLocalizationArgs( &self ) -> Option<Retained<NSArray<NSString>>>

👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
source

pub unsafe fn title(&self) -> Option<Retained<NSString>>

source

pub unsafe fn titleLocalizationKey(&self) -> Option<Retained<NSString>>

source

pub unsafe fn titleLocalizationArgs( &self ) -> Option<Retained<NSArray<NSString>>>

source

pub unsafe fn subtitle(&self) -> Option<Retained<NSString>>

source

pub unsafe fn subtitleLocalizationKey(&self) -> Option<Retained<NSString>>

source

pub unsafe fn subtitleLocalizationArgs( &self ) -> Option<Retained<NSArray<NSString>>>

source

pub unsafe fn alertActionLocalizationKey(&self) -> Option<Retained<NSString>>

👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
source

pub unsafe fn alertLaunchImage(&self) -> Option<Retained<NSString>>

👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
source

pub unsafe fn badge(&self) -> Option<Retained<NSNumber>>

👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
source

pub unsafe fn soundName(&self) -> Option<Retained<NSString>>

👎Deprecated: Interact with UI elements of a CloudKit-server-generated push message via UserNotifications.framework
source

pub unsafe fn category(&self) -> Option<Retained<NSString>>

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.