#[repr(C)]pub struct CKRecordZoneSubscription { /* private fields */ }Available on crate feature
CKSubscription only.Implementations
sourceimpl CKRecordZoneSubscription
impl CKRecordZoneSubscription
pub unsafe fn initWithZoneID( this: Allocated<Self>, zone_id: &CKRecordZoneID ) -> Retained<Self>
👎Deprecated
Available on crate feature
CKRecordZoneID only.pub unsafe fn initWithZoneID_subscriptionID( this: Allocated<Self>, zone_id: &CKRecordZoneID, subscription_id: &CKSubscriptionID ) -> Retained<Self>
Available on crate feature
CKRecordZoneID only.pub unsafe fn initWithCoder( this: Allocated<Self>, a_decoder: &NSCoder ) -> Retained<Self>
pub unsafe fn zoneID(&self) -> Retained<CKRecordZoneID>
Available on crate feature
CKRecordZoneID only.pub unsafe fn recordType(&self) -> Option<Retained<CKRecordType>>
Available on crate feature
CKRecord only.pub unsafe fn setRecordType(&self, record_type: Option<&CKRecordType>)
Available on crate feature
CKRecord only.Methods from Deref<Target = CKSubscription>
pub unsafe fn subscriptionID(&self) -> Retained<CKSubscriptionID>
pub unsafe fn subscriptionType(&self) -> CKSubscriptionType
pub unsafe fn notificationInfo(&self) -> Option<Retained<CKNotificationInfo>>
pub unsafe fn setNotificationInfo( &self, notification_info: Option<&CKNotificationInfo> )
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.