Struct objc2_cloud_kit::CKReference
source · #[repr(C)]pub struct CKReference { /* private fields */ }Available on crate feature
CKReference only.Implementations
impl CKReference
This impl block contains no items.
CKRecordValue
sourceimpl CKReference
impl CKReference
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
pub unsafe fn initWithRecordID_action( this: Allocated<Self>, record_id: &CKRecordID, action: CKReferenceAction ) -> Retained<Self>
Available on crate feature
CKRecordID only.pub unsafe fn initWithRecord_action( this: Allocated<Self>, record: &CKRecord, action: CKReferenceAction ) -> Retained<Self>
Available on crate feature
CKRecord only.pub unsafe fn referenceAction(&self) -> CKReferenceAction
pub unsafe fn recordID(&self) -> Retained<CKRecordID>
Available on crate feature
CKRecordID only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.