#[repr(transparent)]pub struct CKSyncEngineEventType(pub NSInteger);CKSyncEngineEvent only.Expand description
An event that occurs during the operation of a CKSyncEngine.
See CKSyncEngineEvent for more details.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl CKSyncEngineEventType
impl CKSyncEngineEventType
Sourcepub const StateUpdate: Self
pub const StateUpdate: Self
The sync engine state was updated. You should persist it locally.
Sourcepub const AccountChange: Self
pub const AccountChange: Self
The user signed in or out of their account.
Sourcepub const FetchedDatabaseChanges: Self
pub const FetchedDatabaseChanges: Self
The sync engine fetched new database changes from the server.
Sourcepub const FetchedRecordZoneChanges: Self
pub const FetchedRecordZoneChanges: Self
The sync engine fetched new record zone changes from the server.
Sourcepub const SentDatabaseChanges: Self
pub const SentDatabaseChanges: Self
The sync engine sent a batch of database changes to the server.
Sourcepub const SentRecordZoneChanges: Self
pub const SentRecordZoneChanges: Self
The sync engine sent a batch of record zone changes to the server.
Sourcepub const WillFetchChanges: Self
pub const WillFetchChanges: Self
The sync engine is about to fetch changes from the server.
Sourcepub const WillFetchRecordZoneChanges: Self
pub const WillFetchRecordZoneChanges: Self
The sync engine is about to fetch record zone changes from the server for a specific zone.
Sourcepub const DidFetchRecordZoneChanges: Self
pub const DidFetchRecordZoneChanges: Self
The sync engine finished fetching record zone changes from the server for a specific zone.
Sourcepub const DidFetchChanges: Self
pub const DidFetchChanges: Self
The sync engine finished fetching changes from the server.
Sourcepub const WillSendChanges: Self
pub const WillSendChanges: Self
The sync engine is about to send changes to the server.
Sourcepub const DidSendChanges: Self
pub const DidSendChanges: Self
The sync engine finished sending changes to the server.