#[repr(C)]
pub struct CKSyncEngineFetchChangesScope { /* private fields */ }
Available on crate feature CKSyncEngine only.

Implementations

source

impl CKSyncEngineFetchChangesScope

source

pub unsafe fn zoneIDs(&self) -> Option<Retained<NSSet<CKRecordZoneID>>>

Available on crate feature CKRecordZoneID only.
source

pub unsafe fn excludedZoneIDs(&self) -> Retained<NSSet<CKRecordZoneID>>

Available on crate feature CKRecordZoneID only.
source

pub unsafe fn initWithZoneIDs( this: Allocated<Self>, zone_i_ds: Option<&NSSet<CKRecordZoneID>> ) -> Retained<Self>

Available on crate feature CKRecordZoneID only.
source

pub unsafe fn initWithExcludedZoneIDs( this: Allocated<Self>, zone_i_ds: &NSSet<CKRecordZoneID> ) -> Retained<Self>

Available on crate feature CKRecordZoneID only.
source

pub unsafe fn containsZoneID(&self, zone_id: &CKRecordZoneID) -> bool

Available on crate feature CKRecordZoneID only.
source

impl CKSyncEngineFetchChangesScope

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.