#[repr(C)]pub struct CKSyncEngineWillSendChangesEvent { /* private fields */ }Available on crate feature
CKSyncEngineEvent only.Implementations
sourceimpl CKSyncEngineWillSendChangesEvent
impl CKSyncEngineWillSendChangesEvent
pub unsafe fn context(&self) -> Retained<CKSyncEngineSendChangesContext>
Available on crate feature
CKSyncEngine only.Methods from Deref<Target = CKSyncEngineEvent>
pub unsafe fn type(&self) -> CKSyncEngineEventType
pub unsafe fn stateUpdateEvent(&self) -> Retained<CKSyncEngineStateUpdateEvent>
pub unsafe fn accountChangeEvent( &self ) -> Retained<CKSyncEngineAccountChangeEvent>
pub unsafe fn fetchedDatabaseChangesEvent( &self ) -> Retained<CKSyncEngineFetchedDatabaseChangesEvent>
pub unsafe fn fetchedRecordZoneChangesEvent( &self ) -> Retained<CKSyncEngineFetchedRecordZoneChangesEvent>
pub unsafe fn sentDatabaseChangesEvent( &self ) -> Retained<CKSyncEngineSentDatabaseChangesEvent>
pub unsafe fn sentRecordZoneChangesEvent( &self ) -> Retained<CKSyncEngineSentRecordZoneChangesEvent>
pub unsafe fn willFetchChangesEvent( &self ) -> Retained<CKSyncEngineWillFetchChangesEvent>
pub unsafe fn willFetchRecordZoneChangesEvent( &self ) -> Retained<CKSyncEngineWillFetchRecordZoneChangesEvent>
pub unsafe fn didFetchRecordZoneChangesEvent( &self ) -> Retained<CKSyncEngineDidFetchRecordZoneChangesEvent>
pub unsafe fn didFetchChangesEvent( &self ) -> Retained<CKSyncEngineDidFetchChangesEvent>
pub unsafe fn willSendChangesEvent( &self ) -> Retained<CKSyncEngineWillSendChangesEvent>
pub unsafe fn didSendChangesEvent( &self ) -> Retained<CKSyncEngineDidSendChangesEvent>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.