#[repr(transparent)]pub struct CKSyncEngineZoneDeletionReason(pub NSInteger);Available on crate feature
CKSyncEngineEvent only.Expand description
Tuple Fields
0: NSIntegerImplementations
Sourceimpl CKSyncEngineZoneDeletionReason
impl CKSyncEngineZoneDeletionReason
Sourcepub const Purged: Self
pub const Purged: Self
A deletion from the user via the iCloud storage UI. This is an indication that the user wanted all data deleted, so local cached data should be wiped and not re-uploaded to the server.
Sourcepub const EncryptedDataReset: Self
pub const EncryptedDataReset: Self
The user chose to reset all encrypted data for their account. This is an indication that the user had to reset encrypted data during account recovery, so local cached data should be re-uploaded to the server to minimize data loss.