#[repr(C)]pub struct CKSystemSharingUIObserver { /* private fields */ }Available on crate feature
CKSystemSharingUIObserver only.Implementations
sourceimpl CKSystemSharingUIObserver
impl CKSystemSharingUIObserver
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
pub unsafe fn initWithContainer( this: Allocated<Self>, container: &CKContainer ) -> Retained<Self>
Available on crate feature
CKContainer only.Available on crate features
CKRecord and CKRecordID and CKShare and block2 only.Available on crate features
CKRecord and CKRecordID and CKShare and block2 only.pub unsafe fn systemSharingUIDidStopSharingBlock( &self ) -> *mut Block<dyn Fn(NonNull<CKRecordID>, *mut NSError)>
Available on crate features
CKRecordID and block2 only.pub unsafe fn setSystemSharingUIDidStopSharingBlock( &self, system_sharing_ui_did_stop_sharing_block: Option<&Block<dyn Fn(NonNull<CKRecordID>, *mut NSError)>> )
Available on crate features
CKRecordID and block2 only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.