#[repr(C)]pub struct CKUserIdentityLookupInfo { /* private fields */ }Available on crate feature
CKUserIdentityLookupInfo only.Implementations
sourceimpl CKUserIdentityLookupInfo
impl CKUserIdentityLookupInfo
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
pub unsafe fn initWithEmailAddress( this: Allocated<Self>, email_address: &NSString ) -> Retained<Self>
pub unsafe fn initWithPhoneNumber( this: Allocated<Self>, phone_number: &NSString ) -> Retained<Self>
pub unsafe fn initWithUserRecordID( this: Allocated<Self>, user_record_id: &CKRecordID ) -> Retained<Self>
Available on crate feature
CKRecordID only.pub unsafe fn lookupInfosWithEmails( emails: &NSArray<NSString> ) -> Retained<NSArray<CKUserIdentityLookupInfo>>
pub unsafe fn lookupInfosWithPhoneNumbers( phone_numbers: &NSArray<NSString> ) -> Retained<NSArray<CKUserIdentityLookupInfo>>
pub unsafe fn lookupInfosWithRecordIDs( record_i_ds: &NSArray<CKRecordID> ) -> Retained<NSArray<CKUserIdentityLookupInfo>>
Available on crate feature
CKRecordID only.pub unsafe fn emailAddress(&self) -> Option<Retained<NSString>>
pub unsafe fn phoneNumber(&self) -> Option<Retained<NSString>>
pub unsafe fn userRecordID(&self) -> Option<Retained<CKRecordID>>
Available on crate feature
CKRecordID only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.