CKRecordKeyValueSetting

Trait CKRecordKeyValueSetting 

pub unsafe trait CKRecordKeyValueSetting: NSObjectProtocol {
    // Provided methods
    unsafe fn objectForKey(
        &self,
        key: &CKRecordFieldKey,
    ) -> Option<Retained<ProtocolObject<dyn CKRecordValue>>>
       where Self: Sized + Message { ... }
    unsafe fn setObject_forKey(
        &self,
        object: Option<&ProtocolObject<dyn CKRecordValue>>,
        key: &CKRecordFieldKey,
    )
       where Self: Sized + Message { ... }
    unsafe fn objectForKeyedSubscript(
        &self,
        key: &CKRecordFieldKey,
    ) -> Option<Retained<ProtocolObject<dyn CKRecordValue>>>
       where Self: Sized + Message { ... }
    unsafe fn setObject_forKeyedSubscript(
        &self,
        object: Option<&ProtocolObject<dyn CKRecordValue>>,
        key: &CKRecordFieldKey,
    )
       where Self: Sized + Message { ... }
    unsafe fn allKeys(&self) -> Retained<NSArray<CKRecordFieldKey>>
       where Self: Sized + Message { ... }
    unsafe fn changedKeys(&self) -> Retained<NSArray<CKRecordFieldKey>>
       where Self: Sized + Message { ... }
}
Available on crate feature CKRecord only.
Formalizes a protocol for getting and setting keys on a CKRecord. Not intended to be used directly by client code

See also Apple’s documentation

Provided Methods

unsafe fn objectForKey( &self, key: &CKRecordFieldKey, ) -> Option<Retained<ProtocolObject<dyn CKRecordValue>>>
where Self: Sized + Message,

unsafe fn setObject_forKey( &self, object: Option<&ProtocolObject<dyn CKRecordValue>>, key: &CKRecordFieldKey, )
where Self: Sized + Message,

unsafe fn objectForKeyedSubscript( &self, key: &CKRecordFieldKey, ) -> Option<Retained<ProtocolObject<dyn CKRecordValue>>>
where Self: Sized + Message,

unsafe fn setObject_forKeyedSubscript( &self, object: Option<&ProtocolObject<dyn CKRecordValue>>, key: &CKRecordFieldKey, )
where Self: Sized + Message,

unsafe fn allKeys(&self) -> Retained<NSArray<CKRecordFieldKey>>
where Self: Sized + Message,

unsafe fn changedKeys(&self) -> Retained<NSArray<CKRecordFieldKey>>
where Self: Sized + Message,