Struct objc2_cloud_kit::CKContainer
source · #[repr(C)]pub struct CKContainer { /* private fields */ }Available on crate feature
CKContainer only.Implementations
sourceimpl CKContainer
impl CKContainer
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
pub unsafe fn defaultContainer() -> Retained<CKContainer>
pub unsafe fn containerWithIdentifier( container_identifier: &NSString ) -> Retained<CKContainer>
pub unsafe fn containerIdentifier(&self) -> Option<Retained<NSString>>
pub unsafe fn addOperation(&self, operation: &CKOperation)
Available on crate feature
CKOperation only.sourceimpl CKContainer
impl CKContainer
Database
pub unsafe fn privateCloudDatabase(&self) -> Retained<CKDatabase>
Available on crate feature
CKDatabase only.pub unsafe fn publicCloudDatabase(&self) -> Retained<CKDatabase>
Available on crate feature
CKDatabase only.Available on crate feature
CKDatabase only.pub unsafe fn databaseWithDatabaseScope( &self, database_scope: CKDatabaseScope ) -> Retained<CKDatabase>
Available on crate feature
CKDatabase only.sourceimpl CKContainer
impl CKContainer
AccountStatus
pub unsafe fn accountStatusWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(CKAccountStatus, *mut NSError)> )
Available on crate feature
block2 only.sourceimpl CKContainer
impl CKContainer
ApplicationPermission
pub unsafe fn statusForApplicationPermission_completionHandler( &self, application_permission: CKApplicationPermissions, completion_handler: CKApplicationPermissionBlock )
👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate feature
block2 only.pub unsafe fn requestApplicationPermission_completionHandler( &self, application_permission: CKApplicationPermissions, completion_handler: CKApplicationPermissionBlock )
👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate feature
block2 only.sourceimpl CKContainer
impl CKContainer
UserRecords
pub unsafe fn fetchUserRecordIDWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(*mut CKRecordID, *mut NSError)> )
Available on crate features
CKRecordID and block2 only.pub unsafe fn discoverAllIdentitiesWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(*mut NSArray<CKUserIdentity>, *mut NSError)> )
👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features
CKUserIdentity and block2 only.pub unsafe fn discoverUserIdentityWithEmailAddress_completionHandler( &self, email: &NSString, completion_handler: &Block<dyn Fn(*mut CKUserIdentity, *mut NSError)> )
👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features
CKUserIdentity and block2 only.pub unsafe fn discoverUserIdentityWithPhoneNumber_completionHandler( &self, phone_number: &NSString, completion_handler: &Block<dyn Fn(*mut CKUserIdentity, *mut NSError)> )
👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features
CKUserIdentity and block2 only.pub unsafe fn discoverUserIdentityWithUserRecordID_completionHandler( &self, user_record_id: &CKRecordID, completion_handler: &Block<dyn Fn(*mut CKUserIdentity, *mut NSError)> )
👎Deprecated: No longer supported. Please see Sharing CloudKit Data with Other iCloud Users.
Available on crate features
CKRecordID and CKUserIdentity and block2 only.sourceimpl CKContainer
impl CKContainer
Sharing
Available on crate features
CKShareParticipant and block2 only.Available on crate features
CKShareParticipant and block2 only.Available on crate features
CKRecordID and CKShareParticipant and block2 only.Available on crate features
CKShareMetadata and block2 only.Available on crate features
CKRecord and CKShare and CKShareMetadata and block2 only.sourceimpl CKContainer
impl CKContainer
CKLongLivedOperations
pub unsafe fn fetchAllLongLivedOperationIDsWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(*mut NSArray<CKOperationID>, *mut NSError)> )
Available on crate features
CKOperation and block2 only.pub unsafe fn fetchLongLivedOperationWithID_completionHandler( &self, operation_id: &CKOperationID, completion_handler: &Block<dyn Fn(*mut CKOperation, *mut NSError)> )
Available on crate features
CKOperation and block2 only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.